Introduction
============

.. include:: includes/all.rst

The ``debops-contrib.kodi`` role allows you to setup and manage the Kodi_ media center software.


Installation
~~~~~~~~~~~~

This role requires at least Ansible ``v2.1.5``. To install it, run:

.. code-block:: console

   ansible-galaxy install debops-contrib.kodi

..
 Local Variables:
 mode: rst
 ispell-local-dictionary: "american"
 End:
